Define init, txbegin, txend and txputchar macros.
[bertos.git] / cpu / cpu.h
index cf79f7efd4483fbc8c8b1c11ea4f843812a3adad..1e68ac2c2d578e6deadb4e7d778ed6c62c74982d 100644 (file)
--- a/cpu/cpu.h
+++ b/cpu/cpu.h
                        set_CPSR(x); \
                } while (0)
 
-               #define IRQ_GETSTATE() \
+               #define IRQ_ENABLED() \
                        ((bool)(get_CPSR() & 0xb0))
 
                #define BREAKPOINT  /* asm("bkpt 0") DOES NOT WORK */
 
                #define CPU_READ_FLAGS() \
                ({ \
-                       uint32_t sreg; \
+                       cpuflags_t sreg; \
                        asm volatile ( \
                                "mrs %0, cpsr\n\t" \
                                : "=r" (sreg) \
                        sreg; \
                })
 
-               #define IRQ_GETSTATE() (!((CPU_READ_FLAGS() & 0xc0) == 0xc0))
+               #define IRQ_ENABLED() ((CPU_READ_FLAGS() & 0xc0) != 0xc0)
 
                /**
                 * Initialization value for registers in stack frame.
                 * The register index is not directly corrispondent to CPU
* register numbers, but is related to how are pushed to stack (\see asm_switch_context).
* Index (CPU_SAVED_REGS_CNT - 1) is the CPSR register:
* the initial value is taken from current CPSR.
                 */
-               #define CPU_REG_INIT_VALUE(reg) (reg == (CPU_SAVED_REGS_CNT - 1) ? CPU_READ_FLAGS() : 0)
+               #define CPU_REG_INIT_VALUE(reg) (reg == (CPU_SAVED_REGS_CNT - 1) ? 0x13 : 0)
 
        #endif /* !__IAR_SYSTEMS_ICC_ */
 
        #define IRQ_ENABLE          FIXME
        #define IRQ_SAVE_DISABLE(x) FIXME
        #define IRQ_RESTORE(x)      FIXME
-       #define IRQ_GETSTATE()      FIXME
+       #define IRQ_ENABLED()      FIXME
 
        typedef uint32_t cpuflags_t; // FIXME
        typedef uint32_t cpustack_t; // FIXME
        }
        #define IRQ_RUNNING() irq_running()
 
-       static inline bool irq_getstate(void)
+       static inline bool irq_enabled(void)
        {
                uint16_t x;
                asm(move SR,x);
                return !(x & 0x0200);
        }
-       #define IRQ_GETSTATE() irq_getstate()
+       #define IRQ_ENABLED() irq_enabled()
 
        typedef uint16_t cpuflags_t;
        typedef unsigned int cpustack_t;
                ); \
        } while (0)
 
-       #define IRQ_GETSTATE() \
+       #define IRQ_ENABLED() \
        ({ \
                uint8_t sreg; \
                __asm__ __volatile__( \
@@
                 * Initialization value for registers in stack frame.
                 * The register index is not directly corrispondent to CPU
-                * register numbers, but is related to how are pushed to stack (\see asm_switch_context).
-                * Index (CPU_SAVED_REGS_CNT - 1) is the CPSR register:
-                * the initial value is taken from current CPSR.
+                * register numbers, but is related to how are pushed to
+                * stack (\see asm_switch_context).
+                * Index (CPU_SAVED_REGS_CNT - 1) is the CPSR register,
+                * the initial value is set to:
+                * - All flags (N, Z, C, V) set to 0.
+                * - IRQ and FIQ enabled.
+                * - ARM state.
+                * - CPU in Supervisor Mode (SVC).
                 */